@@ -301,8 +301,8 @@ class Query(object):
       encoded query strings are provided to methods that take such strings, like
       load(), add(), set(), remove(), etc.
   """
-  SAFE_KEY_CHARS   = "/?:@-._~!$'()*+,"
-  SAFE_VALUE_CHARS = "/?:@-._~!$'()*+,="
+  SAFE_KEY_CHARS   = "/?:@-._~!$'()*,"
+  SAFE_VALUE_CHARS = "/?:@-._~!$'()*,="
   
   def __init__(self, query='', strict=False):
     self.strict = strict
@@ -1047,6 +1047,11 @@ def urlsplit(url):
 
     http://docs.python.org/library/urlparse.html#urlparse.urlsplit
   """
+  # If a scheme wasn't provided, we shouldn't add one by setting the scheme to
+  # 'http'. We can use urlparse.urlsplit(url) as-is.
+  if '://' not in url:
+    return urlparse.urlsplit(url)
+  
   def _change_urltoks_scheme(tup, scheme):
     l = list(tup)
     l[0] = scheme
